==> G32996_01.zip: language/toc.js <==
define(
{
    
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-840E8268-A821-4BCE-83FE-A4ACAAED68DA"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Java Language Changes Summary",
                    "href":"java-language-changes-summary.html"
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Java Language Changes by Release",
                    "href":"java-language-changes-release.html#GUID-6459681C-6881-45D8-B0DB-395D1BD6DB9B"
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Preview Features",
                    "href":"preview-language-and-vm-features.html"
                },
                {
                    "title":"<span class=\"secnum\">4 </span> Module Import Declarations",
                    "href":"module-import-declarations.html#GUID-E1581E3A-2B0F-4F3B-8FF1-6EBEC8A210DB"
                },
                {
                    "title":"<span class=\"secnum\">5 </span> Flexible Constructor Bodies",
                    "href":"flexible-constructor-bodies.html#GUID-33B53C2C-F20C-4256-9055-9AFC73251AEB"
                },
                {
                    "title":"<span class=\"secnum\">6 </span> Simple Source Files and Instance main Methods",
                    "href":"simple-source-files-and-instance-main-methods.html#GUID-35544A22-61AB-4928-99BB-A9DD1CA062FF"
                },
                {
                    "title":"<span class=\"secnum\">7 </span> Sealed Classes",
                    "href":"sealed-classes-and-interfaces.html"
                },
                {
                    "title":"<span class=\"secnum\">8 </span> Pattern Matching",
                    "href":"pattern-matching.html",
                    "topics":[
                        {
                            "title":"Pattern Matching with instanceof",
                            "href":"pattern-matching-instanceof.html#GUID-843060B5-240C-4F47-A7B0-95C42E5B08A7"
                        },
                        {
                            "title":"Pattern Matching with switch",
                            "href":"pattern-matching-switch.html#GUID-E69EEA63-E204-41B4-AA7F-D58B26A3B232"
                        },
                        {
                            "title":"Type Patterns",
                            "href":"type-patterns.html#GUID-5E59FB7A-1629-4638-B384-1FCE3045463C"
                        },
                        {
                            "title":"Record Patterns",
                            "href":"record-patterns.html#GUID-7623D3AD-4141-4914-A384-60C65BD0C010"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">9 </span> Record Classes",
                    "href":"records.html#GUID-6699E26F-4A9B-4393-A08B-1E47D4B2D263"
                },
                {
                    "title":"<span class=\"secnum\">10 </span> Unnamed Variables and Patterns",
                    "href":"unnamed-variables-and-patterns.html#GUID-D54E1CF1-BDFD-4B57-8A6E-5B4C87F4D58A"
                },
                {
                    "title":"<span class=\"secnum\">11 </span> Switch Expressions and Statements",
                    "href":"switch-expressions-and-statements.html#GUID-BA4F63E3-4823-43C6-A5F3-BAA4A2EF3ADC"
                },
                {
                    "title":"<span class=\"secnum\">12 </span> Text Blocks",
                    "href":"text-blocks.html"
                },
                {
                    "title":"<span class=\"secnum\">13 </span> Local Variable Type Inference",
                    "href":"local-variable-type-inference.html"
                },
                {
                    "title":"<span class=\"secnum\">14 </span> Safe Casting with instanceof and switch",
                    "href":"safe-casting-instanceof-and-switch.html#GUID-6222DB3F-4F81-435C-B0E8-9AB298276549"
                }
            ]
        }
    ]
});

==> G44113_01.zip: language/toc.js <==
define(
{
    
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-840E8268-A821-4BCE-83FE-A4ACAAED68DA"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Java Language Changes Summary",
                    "href":"java-language-changes-summary.html"
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Java Language Changes by Release",
                    "href":"java-language-changes-release.html#GUID-6459681C-6881-45D8-B0DB-395D1BD6DB9B"
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Preview Features",
                    "href":"preview-language-and-vm-features.html"
                },
                {
                    "title":"<span class=\"secnum\">4 </span> Module Import Declarations",
                    "href":"module-import-declarations.html#GUID-E1581E3A-2B0F-4F3B-8FF1-6EBEC8A210DB"
                },
                {
                    "title":"<span class=\"secnum\">5 </span> Flexible Constructor Bodies",
                    "href":"flexible-constructor-bodies.html#GUID-33B53C2C-F20C-4256-9055-9AFC73251AEB"
                },
                {
                    "title":"<span class=\"secnum\">6 </span> Compact Source Files and Instance main Methods",
                    "href":"compact-source-files-and-instance-main-methods.html#GUID-35544A22-61AB-4928-99BB-A9DD1CA062FF"
                },
                {
                    "title":"<span class=\"secnum\">7 </span> Sealed Classes",
                    "href":"sealed-classes-and-interfaces.html"
                },
                {
                    "title":"<span class=\"secnum\">8 </span> Pattern Matching",
                    "href":"pattern-matching.html",
                    "topics":[
                        {
                            "title":"Pattern Matching with instanceof",
                            "href":"pattern-matching-instanceof.html#GUID-843060B5-240C-4F47-A7B0-95C42E5B08A7"
                        },
                        {
                            "title":"Pattern Matching with switch",
                            "href":"pattern-matching-switch.html#GUID-E69EEA63-E204-41B4-AA7F-D58B26A3B232"
                        },
                        {
                            "title":"Type Patterns",
                            "href":"type-patterns.html#GUID-5E59FB7A-1629-4638-B384-1FCE3045463C"
                        },
                        {
                            "title":"Record Patterns",
                            "href":"record-patterns.html#GUID-7623D3AD-4141-4914-A384-60C65BD0C010"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">9 </span> Record Classes",
                    "href":"records.html#GUID-6699E26F-4A9B-4393-A08B-1E47D4B2D263"
                },
                {
                    "title":"<span class=\"secnum\">10 </span> Unnamed Variables and Patterns",
                    "href":"unnamed-variables-and-patterns.html#GUID-D54E1CF1-BDFD-4B57-8A6E-5B4C87F4D58A"
                },
                {
                    "title":"<span class=\"secnum\">11 </span> Switch Expressions and Statements",
                    "href":"switch-expressions-and-statements.html#GUID-BA4F63E3-4823-43C6-A5F3-BAA4A2EF3ADC"
                },
                {
                    "title":"<span class=\"secnum\">12 </span> Text Blocks",
                    "href":"text-blocks.html"
                },
                {
                    "title":"<span class=\"secnum\">13 </span> Local Variable Type Inference",
                    "href":"local-variable-type-inference.html"
                },
                {
                    "title":"<span class=\"secnum\">14 </span> Safe Casting with instanceof and switch",
                    "href":"safe-casting-instanceof-and-switch.html#GUID-6222DB3F-4F81-435C-B0E8-9AB298276549"
                }
            ]
        }
    ]
});
